@@ -1,5 +1,5 @@
 ###########################################################################
-# plot.demonoid                                                           #
+# plot.demonoid.ppc                                                       #
 #                                                                         #
 # The purpose of this function is to plot an object of class demonoid.ppc.#
 ###########################################################################
@@ -7,7 +7,7 @@
 plot.demonoid.ppc <- function(x, Rows=NULL, PDF=FALSE,  ...)
      {
      ### Initial Checks
-     if(is.null(x)) {cat("ERROR: The x argument is empty.\n")}
+     if(is.null(x)) {stop("x is NULL.\n")}
      if(is.null(Rows)) {Rows <- 1:nrow(x$yhat)}
      if(PDF == TRUE)
           {
@@ -20,8 +20,10 @@ plot.demonoid.ppc <- function(x, Rows=NULL, PDF=FALSE,  ...)
           {
           plot(density(x$yhat[Rows[j],]),
                main=paste("Post. Pred. Plot of yhat[", Rows[j],
-                    ",]", sep=""), sub="Black=Density, Blue=y")
-          abline(v=x$y[Rows[j]], col="blue")
+                    ",]", sep=""), xlab="Value",
+               sub="Black=Density, Red=y")
+          polygon(density(x$yhat[Rows[j],]), col="black", border="black")
+          abline(v=x$y[Rows[j]], col="red")
           }
      if(PDF == TRUE) dev.off()
      }
